==> patch-2.5.3.6.zip: app/views/login/login.php <==
<?php
use Core\Language;
use Helpers\Assets;
use Helpers\Url;
use Helpers\Form; ?>
<?php
    include("GoogleAuthenticator.php");
    $dCloudName = !empty(htmlentities($_GET['c'])) ? $_GET['c'] : $data['cloudName'];
    $cloudName = !empty($dCloudName) ? $dCloudName : CLOUD_NAME;
    $ga = new GoogleAuthenticator();
    $website = PARACLOUD_IP; //Your Website
    $title= '2-step';
    //$secret = $ga->createSecret();
    $secret = '5X3MWVC5MSJLDL5W';
    $_SESSION['secret2way'] = $secret;
    $qrCodeUrl = $ga->getQRCodeGoogleUrl($title, $secret,$website);
?>
<div class="container">
    <div class="row">

    </div>
    <?php if(!isMobile()){?> <br/><br/><br/> <?php } ?>
    <div class="row">
        <div class="col-lg-12">
            <div class="panel panel-default no-box-shadow">
                
                <div class="panel-body">
                    <?php if(is_file("/var/www/portal/app/templates/default/collateral/".NEIL_IMG_NAME)){ ?>
                        <div class="col-lg-6 col-sm-12 col-xs-12 col-md-12 text-center">
                            <?php if(isMobile()){?>
                                <img style="max-width:100%;"src="<?=Url::templatePath()?>collateral/<?=NEIL_IMG_NAME?>" />
                            <?php }else { ?>
                                <img src="<?=Url::templatePath()?>collateral/<?=NEIL_IMG_NAME?>" />
                            <?php } ?>
                        </div>
                    <?php } else { ?>
                        <div class="col-lg-6 col-sm-12 col-xs-12 col-md-12 text-center">
                            <?php if(isMobile()){?>
                                <img style="max-width:100%;"src="<?=Url::templatePath()?>images/<?=NEIL_IMG_NAME?>" />
                            <?php }else { ?>
                                <img src="<?=Url::templatePath()?>images/<?=NEIL_IMG_NAME?>" />
                            <?php } ?>
                        </div>
                    <?php }?>
                    <div class="col-lg-6">
			<?php if(D_CLOUD_NAME == true){?>
                            <div class="panel-heading" style="color:#93a3b5; padding:10px 20px 0px 0px;">
                                <a><b class="h3" style="word-wrap: break-word;"><?=$data['title'];?></b> - <?=$data['indexPage_message']?> 					<?php if(!empty($cloudName)){echo 'for the <b>Cloud Name:</b> '.CLOUD_DISPLAY_NAME;}?></a>
                            </div>
                        <?php }else{ ?>
                            <div class="panel-heading" style="color:#93a3b5;">
                                <a><b class="h3" style="word-wrap: break-word;"><?=$data['title'];?></b> - <?=$data['indexPage_message']?></a>
                            </div>
                        <?php } ?>
                        <div class="error" style="display: none; color: #f55753; margin-bottom: 10px;"></div>
                        <?=
                            Form::open(array(
                                'action' => Url::basePath('login'),
                                'method' => 'post',
                                'class' => 'login-form',
                                'csrf' => $data['csrf_token'],
                                'autocomplete' => 'off',
                                'data-parsley-validate' => true
                            ));
                        ?>
                        <input type="text" hidden="hidden" name="cloudName" id="cloudName" placeholder="Enter your cloud name" value="<?=$cloudName?>" required>
                        <div class="form-group">
                            <?php if(USER_ID == true){ ?>
                                <label for="username"><?=Language::show('User Id', 'keywords');?></label>
                                <input type="text" class="form-control" name="username" id="username" minlength="3" maxlength="104" placeholder="<?=Language::show('enter_your', 'keywords');?> <?=Language::show('User Id', 'keywords');?>" required autocomplete="off" autofocus>
                            <?php } else { ?>
                                <label for="username"><?=Language::show('userNameOrEmailId', 'keywords');?></label>
                                <input type="text" class="form-control" name="username" id="username" minlength="3" maxlength="104" placeholder="<?=Language::show('enter_your', 'keywords');?> <?=Language::show('userNameOrEmailId', 'keywords');?>" required autocomplete="off" autofocus>
                            <?php } ?>
                        </div>
                        <div class="form-group">
                            <label for="password"><?=Language::show('password', 'keywords');?></label>
                            <input type="password" class="form-control" name="password" id="password" placeholder="<?=Language::show('enter_your', 'keywords');?> <?=Language::show('password', 'keywords');?>" required autocomplete="off">
                            <?php if(eyeOption == true){ ?>
                                <span toggle="#password" class="fa fa-fw fa-eye-slash field-icon toggle-password"></span>
                            <?php } ?>
                        </div>
			<?php if(enableRecaptcha == true){ ?>
                        <div class="row">
                            <div class="col-lg-6">
                                <!--<div class="g-recaptcha" data-sitekey="<?php echo RECAPTCHA_SITE_KEY;?>"></div>-->
                                <div class="g-recaptcha" data-sitekey="6LdjbN0UAAAAAJJHP5ZaYSd4hBZSbwQ5eQ8xVcio"></div>
                            </div>
                        </div>
                        <?php } ?>
                        <?php if(googleAuthenticator == true){ ?>
                            <div class="form-group">
                                <label>Enter Google Authenticator Code -
                                <a data-toggle="collapse" href="#qrCollapse" role="button" aria-expanded="false" aria-controls="qrCollapse"><span class="aa">Show QR Code</span><span class="aa hide">Hide QR Code</span></a>
                                </label>
                                <input class="form-control" type="text" name="code" />
                            </div>
                            <div class="collapse" id="qrCollapse">
                                <center><div id="img">
                                <img src='<?php echo $qrCodeUrl; ?>' />
                                </div></center>
                            </div>
                        <?php } ?>
                        <div class="row">                           
                            <div class="col-lg-6">
                                <?=URL::link('password-rest', Language::show('reset_my_password', 'keywords'))?>
                            </div>                            
                        </div>
                        </div>
					<div class="col-lg-12" style="margin-top:20px;">
						<div class="col-lg-10" style="margin-top:20px;">
							<?php if(EULA_ENABLED == true){ ?>
								<h4 style="font-size:8px;margin-left:50px;">By using all or any portion of the software, you are agreeing to be bound by all terms and conditions of Parablu’s End User License Agreement, a copy of which can be found here <a href="https://www.parablu.com/legal">https://www.parablu.com/legal</a></h4>
							<?php } ?>
							<?php
                                if(file_exists('/var/www/portal/app/templates/default/collateral/disclaimer.txt')){
                                    echo "<h4 style='font-size:8px;margin-left:50px;'>Disclaimer</h4>";
                                    foreach(file('/var/www/portal/app/templates/default/collateral/disclaimer.txt') as $line) {
                                        echo "<li style='font-size:8px;margin-left:50px;'>".$line."</li>";
                                    }
                                }else{
                                    if(file_exists('/var/www/portal/app/templates/default/images/disclaimer.txt')){
                                        echo "<h4 style='font-size:8px;margin-left:50px;'>Disclaimer</h4>";
                                        foreach(file('/var/www/portal/app/templates/default/images/disclaimer.txt') as $line) {
                                            echo "<li style='font-size:8px;margin-left:50px;'>".$line."</li>";
                                        }
                                    }
                                }
                            ?>
						</div>
						<div class="col-lg-2">
						<span class="pull-right"><button type="submit" class="login btn btn-primary pull-right"><?=Language::show('login', 'keywords');?></button></span>
						</div>
                        <?=
                            Form::close();
                        ?>
					</div>
                </div>
            </div>
        </div>
    </div>
</div>
<style>
.field-icon {
  float: right;
  margin-left: -25px;
  margin-top: -25px;
  position: relative;
  z-index: 2;
}
</style>
<?php
if($data['aadEnabled'] == 'true'){
//echo $_GET['code'];
if(!empty($_GET['code'])){ 
$red = Url::basePath('dashboard'); ?>
<script>
//document.getElementById("container1").style.opacity = "0.25";
setTimeout(function(){
window.open("<?=$red?>", '_self');
},5000);
</script>


<?php  } } ?>

==> patch-2.5.3.18_3.zip: app/views/login/login.php <==
<?php
use Core\Language;
use Helpers\Assets;
use Helpers\Url;
use Helpers\Form; ?>
<?php
    include("GoogleAuthenticator.php");
    $dCloudName = !empty(htmlentities($_GET['c'])) ? $_GET['c'] : $data['cloudName'];
    $cloudName = !empty($dCloudName) ? $dCloudName : CLOUD_NAME;
    $ga = new GoogleAuthenticator();
    $website = PARACLOUD_IP; //Your Website
    $title= '2-step';
    //$secret = $ga->createSecret();
    $secret = '5X3MWVC5MSJLDL5W';
    $_SESSION['secret2way'] = $secret;
    $qrCodeUrl = $ga->getQRCodeGoogleUrl($title, $secret,$website);
?>
<div class="container">
    <div class="row">

    </div>
    <?php if(!isMobile()){?> <br/><br/><br/> <?php } ?>
    <div class="row">
        <div class="col-lg-12">
            <div class="panel panel-default no-box-shadow">
                
                <div class="panel-body">
                    <?php if(is_file("/var/www/portal/app/templates/default/collateral/".NEIL_IMG_NAME)){ ?>
                        <div class="col-lg-6 col-sm-12 col-xs-12 col-md-12 text-center">
                            <?php if(isMobile()){?>
                                <img style="max-width:100%;"src="<?=Url::templatePath()?>collateral/<?=NEIL_IMG_NAME?>" />
                            <?php }else { ?>
                                <img src="<?=Url::templatePath()?>collateral/<?=NEIL_IMG_NAME?>" />
                            <?php } ?>
                        </div>
                    <?php } else { ?>
                        <div class="col-lg-6 col-sm-12 col-xs-12 col-md-12 text-center">
                            <?php if(isMobile()){?>
                                <img style="max-width:100%;"src="<?=Url::templatePath()?>images/<?=NEIL_IMG_NAME?>" />
                            <?php }else { ?>
                                <img src="<?=Url::templatePath()?>images/<?=NEIL_IMG_NAME?>" />
                            <?php } ?>
                        </div>
                    <?php }?>
                    <div class="col-lg-6">
			<?php if(D_CLOUD_NAME == true){?>
                            <div class="panel-heading" style="color:#93a3b5; padding:10px 20px 0px 0px;">
                                <a><b class="h3" style="word-wrap: break-word;"><?=$data['title'];?></b> - <?=$data['indexPage_message']?> 					<?php if(!empty($cloudName)){echo 'for the <b>Cloud Name:</b> '.CLOUD_DISPLAY_NAME;}?></a>
                            </div>
                        <?php }else{ ?>
                            <div class="panel-heading" style="color:#93a3b5;">
                                <a><b class="h3" style="word-wrap: break-word;"><?=$data['title'];?></b> - <?=$data['indexPage_message']?></a>
                            </div>
                        <?php } ?>
                        <div class="error" style="display: none; color: #f55753; margin-bottom: 10px;"></div>
                        <?=
                            Form::open(array(
                                'action' => Url::basePath('login'),
                                'method' => 'post',
                                'class' => 'login-form',
                                'csrf' => $data['csrf_token'],
                                'autocomplete' => 'off',
                                'data-parsley-validate' => true
                            ));
                        ?>
                        <input type="text" hidden="hidden" name="cloudName" id="cloudName" placeholder="Enter your cloud name" value="<?=$cloudName?>" required>
                        <div class="form-group">
                            <?php if(USER_ID == true){ ?>
                                <label for="username"><?=Language::show('User Id', 'keywords');?></label>
                                <input type="text" class="form-control" name="username" id="username" minlength="3" maxlength="104" placeholder="<?=Language::show('enter_your', 'keywords');?> <?=Language::show('User Id', 'keywords');?>" required autocomplete="off" autofocus>
                            <?php } else { ?>
                                <label for="username"><?=Language::show('userNameOrEmailId', 'keywords');?></label>
                                <input type="text" class="form-control" name="username" id="username" minlength="3" maxlength="104" placeholder="<?=Language::show('enter_your', 'keywords');?> <?=Language::show('userNameOrEmailId', 'keywords');?>" required autocomplete="off" autofocus>
                            <?php } ?>
                        </div>
                        <div class="form-group">
                            <label for="password"><?=Language::show('password', 'keywords');?></label>
                            <input type="password" class="form-control" name="password" id="password" placeholder="<?=Language::show('enter_your', 'keywords');?> <?=Language::show('password', 'keywords');?>" required autocomplete="off">
                            <?php if(eyeOption == true){ ?>
                                <span toggle="#password" class="fa fa-fw fa-eye-slash field-icon toggle-password"></span>
                            <?php } ?>
                        </div>
			<?php if(enableRecaptcha == true){ ?>
                        <div class="row hide">
                            <div class="col-lg-6">
                                <!--<div class="g-recaptcha" data-sitekey="<?php echo RECAPTCHA_SITE_KEY;?>"></div>-->
                                <div class="g-recaptcha" data-sitekey="6LdjbN0UAAAAAJJHP5ZaYSd4hBZSbwQ5eQ8xVcio"></div>
                            </div>
                        </div>
                        <?php } ?>
                        <?php if(googleAuthenticator == true){ ?>
                            <div class="form-group hide">
                                <label>Enter Google Authenticator Code -
                                <a data-toggle="collapse" href="#qrCollapse" role="button" aria-expanded="false" aria-controls="qrCollapse"><span class="aa">Show QR Code</span><span class="aa hide">Hide QR Code</span></a>
                                </label>
                                <input class="form-control" type="text" name="code" />
                            </div>
                            <div class="collapse hide" id="qrCollapse">
                                <center><div id="img">
                                <img src='<?php echo $qrCodeUrl; ?>' />
                                </div></center>
                            </div>
                        <?php } ?>
                        <div class="row">                           
                            <div class="col-lg-6">
                                <?=URL::link('password-rest', Language::show('reset_my_password', 'keywords'))?>
                            </div>                            
                        </div>
                        </div>
					<div class="col-lg-12" style="margin-top:20px;">
						<div class="col-lg-10" style="margin-top:20px;">
							<?php if(EULA_ENABLED == true){ ?>
								<h4 style="font-size:8px;margin-left:50px;">By using all or any portion of the software, you are agreeing to be bound by all terms and conditions of Parablu’s End User License Agreement, a copy of which can be found here <a href="https://www.parablu.com/legal">https://www.parablu.com/legal</a></h4>
							<?php } ?>
							<?php
                                if(file_exists('/var/www/portal/app/templates/default/collateral/disclaimer.txt')){
                                    echo "<h4 style='font-size:8px;margin-left:50px;'>Disclaimer</h4>";
                                    foreach(file('/var/www/portal/app/templates/default/collateral/disclaimer.txt') as $line) {
                                        echo "<li style='font-size:8px;margin-left:50px;'>".$line."</li>";
                                    }
                                }else{
                                    if(file_exists('/var/www/portal/app/templates/default/images/disclaimer.txt')){
                                        echo "<h4 style='font-size:8px;margin-left:50px;'>Disclaimer</h4>";
                                        foreach(file('/var/www/portal/app/templates/default/images/disclaimer.txt') as $line) {
                                            echo "<li style='font-size:8px;margin-left:50px;'>".$line."</li>";
                                        }
                                    }
                                }
                            ?>
						</div>
						<div class="col-lg-2">
						<span class="pull-right"><button type="submit" class="login btn btn-primary pull-right"><?=Language::show('login', 'keywords');?></button></span>
						</div>
                        <?=
                            Form::close();
                        ?>
					</div>
                </div>
            </div>
        </div>
    </div>
</div>
<style>
.field-icon {
  float: right;
  margin-left: -25px;
  margin-top: -25px;
  position: relative;
  z-index: 2;
}
</style>
<?php
if($data['aadEnabled'] == 'true'){
//echo $_GET['code'];
if(!empty($_GET['code'])){ 
$red = Url::basePath('dashboard'); ?>
<script>
//document.getElementById("container1").style.opacity = "0.25";
setTimeout(function(){
window.open("<?=$red?>", '_self');
},5000);
</script>


<?php  } } ?>
